==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/pl.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Ładowanie podglądu...",
    "Saved" : "Zapisano",
    "Admin" : "Admin",
    "a safe home for all your data" : "bezpieczna schowek dla wszystkich twoich danych",
    "The given name is too long" : "Wpisana nazwa jest zbyt długi",
    "The given web address is too long" : "Wpisany adres internetowy jest zbyt długi",
    "The given slogan is too long" : "Wpisany slogan jest zbyt długi",
    "The given color is invalid" : "Podany kolor jest nieprawidłowy",
    "No file uploaded" : "Nie wysłano pliku",
    "Unsupported image type" : "Nieobsługiwany typ zdjęcia",
    "You are already using a custom theme" : "Używasz już motywu niestandarowego",
    "Theming" : "Motyw",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Motywy pozwalają na łatwą personalizację wyglądu Twojej instancji i wpsieranych klientów. Efekty będą widoczne dla wszystkich użytkowników.",
    "Name" : "Nazwa",
    "reset to default" : "przywróć domyślne",
    "Web address" : "adres internetowy",
    "Web address https://…" : "adres internetowy https://...",
    "Slogan" : "Slogan",
    "Color" : "Kolor",
    "Logo" : "Logo",
    "Upload new logo" : "Wyślij nowe logo",
    "Login image" : "Obraz logowania",
    "Upload new login background" : "Wyślij nowe tło ekranu logowania",
    "Remove background image" : "Usuń obraz tła",
    "Log in image" : "Zdjęcie logowania"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>=14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/pl.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Ładowanie podglądu...",
    "Saved" : "Zapisano",
    "Admin" : "Admin",
    "a safe home for all your data" : "bezpieczna schowek dla wszystkich twoich danych",
    "The given name is too long" : "Wpisana nazwa jest zbyt długi",
    "The given web address is too long" : "Wpisany adres internetowy jest zbyt długi",
    "The given slogan is too long" : "Wpisany slogan jest zbyt długi",
    "The given color is invalid" : "Podany kolor jest nieprawidłowy",
    "No file uploaded" : "Nie wysłano pliku",
    "Unsupported image type" : "Nieobsługiwany typ zdjęcia",
    "You are already using a custom theme" : "Używasz już motywu niestandarowego",
    "Theming" : "Motyw",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Motywy pozwalają na łatwą personalizację wyglądu Twojej instancji i wpsieranych klientów. Efekty będą widoczne dla wszystkich użytkowników.",
    "Name" : "Nazwa",
    "Reset to default" : "Przywróć domyślne",
    "Web address" : "adres internetowy",
    "Web address https://…" : "adres internetowy https://...",
    "Slogan" : "Slogan",
    "Color" : "Kolor",
    "Logo" : "Logo",
    "Upload new logo" : "Wyślij nowe logo",
    "Login image" : "Obraz logowania",
    "Upload new login background" : "Wyślij nowe tło ekranu logowania",
    "Remove background image" : "Usuń obraz tła",
    "reset to default" : "przywróć domyślne",
    "Log in image" : "Zdjęcie logowania"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
